#Aqueduct - Compliance Remediation Content
#Copyright (C) 2011,2012  Vincent C. Passaro (vincent.passaro@gmail.com)
#
#This program is free software; you can redistribute it and/or
#modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation; either version 2
#of the License, or (at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 51 Franklin Street, Fifth Floor,
#Boston, MA  02110-1301, USA.

#!/bin/bash
######################################################################
#By Tummy a.k.a Vincent C. Passaro				     #
#Vincent[.]Passaro[@]gmail[.]com	         		     #
#www.vincentpassaro.com						     #
######################################################################
#_____________________________________________________________________
#|  Version |   Change Information  |      Author        |    Date    |
#|__________|_______________________|____________________|____________|
#|    1.0   |   Initial Script      | Vincent C. Passaro | 20-oct-2011|
#|	    |   Creation	    |                    |            |
#|__________|_______________________|____________________|____________|
								     

#######################DISA INFORMATION###############################
#Group ID (Vulid): V-11948-2
#Group Title: The system-auth file must be included in any pam definition
#Rule ID: SV-27118-2r1_rule
#Severity: CAT II
#Rule Version (STIG-ID): GEN0000600-2
#Rule Title: Ensure that global settings defined in system-auth are 
#applied in the pam.d definition files.
#
#Vulnerability Discussion: Pam global requirements are generally 
#defined in the /etc/pam.d/system-auth or /etc/pam.d/system-auth-ac 
#file. In order for the requirements to be applied the file containing 
#them must be included directly or indirectly in each program's 
#definition file in /etc/pam.d
#
#Responsibility: System Administrator
#IAControls: IAIA-1, IAIA-2
#
#Check Content: 
#Verify that system-auth settings are being applied.
#
#Procedure:
#Verify that additional pam.d requirements are in use.
#The file "/etc/pam.d/system-auth-ac" is autogenerated by "authconfig". 
#Any manual changes made to it will be lost next time "authconfig" is run. 
#Check to see if the system default of the symlink "/etc/pam.d/system-auth" 
#pointing to "/etc/pam.d/system-auth-ac" has been changed.
#
#ls -l /etc/pam.d/system-auth
#
#If the symlink points to "/etc/pam.d/system-auth-ac", manual changes 
#can not be protected. This is a finding.
#
#grep system-auth-ac /etc/system-auth;
#
#The local system-auth file pointed to by "/etc/pam.d/system-auth" 
#must contain includes to "/etc/pam.d/system-auth-ac" for the auth, 
#account, password, and session lines. If these it does not the 
#parameters maintained by "authconfig" will not be applied. This is a finding.
#
#
#Fix Text: In the default distribution of RHEL5 "/etc/pam.d/system-auth" 
#is a symlink "/etc/pam.d/system-auth-ac" which is an autogenerated file. 
#When a site adds password requirements a new system-auth-local file must 
#be created with only the additional requirements and includes for auth,
#account,passwd and session pointing to "/etc/pam.d/system-auth-ac". Then 
#the symlink "/etc/system-auth" is modified to point to 
#"/etc/pam.d/system-auth-local". This way any changes made do not get 
#lost when "/etc/pam.d/system-auth-ac" is regenerated and each program's 
#pam.d definition file need only have "include system-auth" for auth,
#account,passwd and session, as needed, in order to assure the 
#password requirements will be applied to it. 
#######################DISA INFORMATION###############################

#Global Variables#
PDI=GEN0000600-2

#Start-Lockdown

#Addressed in GEN000460



